pub enum IpDefragError {
UnalignedFragmentPayloadLen {
offset: IpFragOffset,
payload_len: usize,
},
SegmentTooBig {
offset: IpFragOffset,
payload_len: usize,
max: u16,
},
ConflictingEnd {
previous_end: u16,
conflicting_end: u16,
},
AllocationFailure {
len: usize,
},
}Available on crate feature
std only.Variants
UnalignedFragmentPayloadLen
Error if a payload lenght of a IP Fragment packet is not a multiple of 16 and the “more fragments” flag is set.
SegmentTooBig
Error if a segment is bigger then the maximum allowed size.
ConflictingEnd
Error if multiple TP segments were received with the “more segment” unset and differing end points.
Fields
AllocationFailure
Error if not enough memory could be allocated to store the TP payload.