Enum etherparse::TcpOptionWriteError [−][src]
pub enum TcpOptionWriteError {
NotEnoughSpace(usize),
}Errors that can occour when setting the options of a tcp header.
Variants
NotEnoughSpace(usize)There is not enough memory to store all options in the options section of the header (maximum 40 bytes).
The options size is limited by the 4 bit data_offset field in the header which describes the total tcp header size in multiple of 4 bytes. This leads to a maximum size for the options part of the header of 4*(15 - 5) (minus 5 for the size of the tcp header itself).