pub enum BuildVecWriteError {
PayloadLen(ValueTooBigError<usize>),
Ipv4Exts(ExtsWalkError),
Ipv6Exts(ExtsWalkError),
Icmpv6InIpv4,
ArpHeaderNotMatch,
}Available on crate feature
alloc only.Expand description
Error while serializing a packet into a alloc::vec::Vec.
Variants
PayloadLen(ValueTooBigError<usize>)
Error if the length of the payload is too big to be representable by the length fields.
Ipv4Exts(ExtsWalkError)
Error if the IPv4 extensions can not be serialized because of internal consistency errors.
Ipv6Exts(ExtsWalkError)
Error if the IPv6 extensions can not be serialized because of internal consistency errors.
Icmpv6InIpv4
Error if ICMPv6 is packaged in an IPv4 packet (it is undefined how to calculate the checksum).
ArpHeaderNotMatch
Address size defined in the ARP header does not match the actual size.