ParameterProblemCode

Enum ParameterProblemCode 

pub enum ParameterProblemCode {
    ErroneousHeaderField = 0,
    UnrecognizedNextHeader = 1,
    UnrecognizedIpv6Option = 2,
    Ipv6FirstFragmentIncompleteHeaderChain = 3,
    SrUpperLayerHeaderError = 4,
    UnrecognizedNextHeaderByIntermediateNode = 5,
    ExtensionHeaderTooBig = 6,
    ExtensionHeaderChainTooLong = 7,
    TooManyExtensionHeaders = 8,
    TooManyOptionsInExtensionHeader = 9,
    OptionTooBig = 10,
}
Variants



ErroneousHeaderField = 0

Erroneous header field encountered (from RFC 4443)



UnrecognizedNextHeader = 1

Unrecognized Next Header type encountered (from RFC 4443)



UnrecognizedIpv6Option = 2

Unrecognized IPv6 option encountered (from RFC 4443)



Ipv6FirstFragmentIncompleteHeaderChain = 3

IPv6 First Fragment has incomplete IPv6 Header Chain (from RFC 7112)



SrUpperLayerHeaderError = 4

SR Upper-layer Header Error (from RFC 8754).



UnrecognizedNextHeaderByIntermediateNode = 5

Unrecognized Next Header type encountered by intermediate node (from RFC 8883)



ExtensionHeaderTooBig = 6

Extension header too big (from RFC 8883)



ExtensionHeaderChainTooLong = 7

Extension header chain too long (from RFC 8883)



TooManyExtensionHeaders = 8

Too many extension headers (from RFC 8883)



TooManyOptionsInExtensionHeader = 9

Too many options in extension header (from RFC 8883)



OptionTooBig = 10

Option too big (from RFC 8883)

Implementations

Source

impl ParameterProblemCode

pub fn from_u8(code_u8: u8) -> Option<ParameterProblemCode>

Tries to convert a code u8 value to a ParameterProblemCode value.

Returns None in case the code value is not known as a parameter problem code.

pub fn code_u8(&self) -> u8

Returns the u8 value of the code.