Struct etherparse::icmpv6::ParameterProblemHeader
source · pub struct ParameterProblemHeader {
pub code: ParameterProblemCode,
pub pointer: u32,
}Expand description
ICMPv6 parameter problem header.
Fields
code: ParameterProblemCodeThe code can offer additional informations about what kind of parameter problem caused the error.
pointer: u32Identifies the octet offset within the invoking packet where the error was detected.
The pointer will point beyond the end of the ICMPv6 packet if the field in error is beyond what can fit in the maximum size of an ICMPv6 error message.