pub struct RouterAdvertisementPayload {
pub reachable_time: u32,
pub retrans_timer: u32,
}Expand description
Owned payload of a Router Advertisement message (RFC 4861, Section 4.2).
The full packet layout is:
0 1 2 3
0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Type | Code | Checksum |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Cur Hop Limit |M|O| Reserved | Router Lifetime |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Reachable Time |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Retrans Timer |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Options ...
+-+-+-+-+-+-+-+-+-+-+-+-In this crate, Cur Hop Limit, M, O, and Router Lifetime are represented by
crate::icmpv6::RouterAdvertisementHeader in crate::Icmpv6Type::RouterAdvertisement.
This payload struct represents the fixed bytes after that:
Reachable TimeRetrans Timer
Fields
reachable_time: u32Reachable time in milliseconds.
retrans_timer: u32Retransmit timer in milliseconds.
Implementations