TimeExceededPayloadSlice

Struct TimeExceededPayloadSlice 

pub struct TimeExceededPayloadSlice<'a> { /* private fields */ }
Borrowed payload of a Time Exceeded message (RFC 4443, Section 3.3).

The full packet layout is:

 0                   1                   2                   3
 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
|     Type      |     Code      |          Checksum             |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
|                             Unused                            |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
|                    As much of invoking packet                 |
+                as possible without the ICMPv6 packet          +
|                exceeding the minimum IPv6 MTU [IPv6]          |

In this crate, Type, Code, and Unused are represented by crate::Icmpv6Type::TimeExceeded. This slice represents the invoking packet bytes after that fixed part.

Implementations

Source

impl<'a> TimeExceededPayloadSlice<'a>

pub fn from_slice(slice: &'a [u8]) -> Result<Self, LenError>

Creates a payload slice from the bytes after the ICMPv6 header.

pub fn slice(&self) -> &'a [u8]

Returns the full payload slice.

pub fn invoking_packet(&self) -> &'a [u8]

Returns the invoking packet bytes carried by the message.

pub fn as_lax_ip_slice( &self, ) -> Result<(LaxIpSlice<'a>, Option<(HeaderSliceError, Layer)>), LaxHeaderSliceError>

Decodes the invoking packet bytes as a lax IP slice.