pub struct MembershipQueryType {
pub max_response_time: u8,
pub group_address: GroupAddress,
}Expand description
IGMPv1/IGMPv2 Membership Query message type.
IGMPv1 & IGMPv2 can be distinguished via the max_response_time field:
- For IGMPv1 the
max_response_timefield is set to zero - For IGMPv2 the
max_response_timefield is set to NOT zero
0 1 2 3
0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Type = 0x11 | Max Resp Time | Checksum |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Group Address |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+Fields
max_response_time: u8The maximum response time for the membership report (only for IGMPv2, set to 0 for IGMPv1).
Specifies the maximum allowed time before sending a responding report in units of 1/10 second.
For IGMPv1, this field is always set to zero.
group_address: GroupAddressThe group address being queried.
Set to zero for general queries, to learn which groups have members on an attached network. Filled for group-specific queries to learn if a particular group has members on an attached network.
For IGMPv1, this field is always set to zero.
Implementations
Sourceimpl MembershipQueryType
impl MembershipQueryType
Sourcepub const LEN: usize = 8
pub const LEN: usize = 8
Number of bytes/octets an MembershipQueryType takes up in serialized form.