MembershipReportV3Header

Struct MembershipReportV3Header 

pub struct MembershipReportV3Header {
    pub flags: [u8; 2],
    pub num_of_records: u16,
}
IGMPv3 Membership Report Message header part.

Note that the checksum is not stored in this type and is stored in crate::IgmpHeader.

0                   1                   2                   3
0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+  -
|  Type = 0x22  |    Reserved   |           Checksum            |  | part of header &
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+  | this type
|             Flags             |  Number of Group Records (M)  |  ↓
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+  -
|                                                               |  |
.                                                               .  |
.                        Group Record [1]                       .  |
.                                                               .  |
|                                                               |  |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+  |
|                                                               |  |
.                                                               .  |
.                        Group Record [2]                       .  | part of payload
.                                                               .  |
|                                                               |  |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+  |
|                               .                               |  |
.                               .                               .  |
|                               .                               |  |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+  |
|                                                               |  |
.                                                               .  |
.                        Group Record [M]                       .  |
.                                                               .  |
|                                                               |  ↓
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+  -

Fields

flags: [u8; 2]num_of_records: u16

The number of group records in the membership report

Implementations

Source

impl MembershipReportV3Header

pub const LEN: usize = 8

Number of bytes/octets an MembershipReportV3Header takes up in serialized form.

pub const FLAGS_0_EXTENSION_MASK: u8 = 0b0000_0001

Mask of “extension” flag in MembershipReportV3Header::flags[0].