Struct etherparse::Ethernet2Header [−][src]
Ethernet II header.
Fields
source: [u8; 6]
destination: [u8; 6]
ether_type: u16
Methods
impl Ethernet2Header[src]
impl Ethernet2Headerpub fn read<T: Read + Seek + Sized>(
reader: &mut T
) -> Result<Ethernet2Header, Error>[src]
pub fn read<T: Read + Seek + Sized>(
reader: &mut T
) -> Result<Ethernet2Header, Error>Reads an Ethernet-II header from the current position of the read argument.
pub fn write<T: Write + Sized>(&self, writer: &mut T) -> Result<(), Error>[src]
pub fn write<T: Write + Sized>(&self, writer: &mut T) -> Result<(), Error>Writes a given Ethernet-II header to the current position of the write argument.