Struct etherparse::IcmpEchoHeader
source · Expand description
Echo Request & Response common parts between ICMPv4 and ICMPv6.
RFC 4443 Description (ICMPv6)
Every node MUST implement an ICMPv6 Echo responder function that receives Echo Requests and originates corresponding Echo Replies. A node SHOULD also implement an application-layer interface for originating Echo Requests and receiving Echo Replies, for diagnostic purposes.
Fields
id: u16An identifier to aid in matching Echo Replies to Echo Requests. May be zero.
seq: u16A sequence number to aid in matching Echo Replies to Echo Requests. May be zero.
Implementations
sourceimpl IcmpEchoHeader
impl IcmpEchoHeader
sourcepub fn from_bytes(bytes5to8: [u8; 4]) -> IcmpEchoHeader
pub fn from_bytes(bytes5to8: [u8; 4]) -> IcmpEchoHeader
Decodes the seq + id from the on the wire format.