Struct etherparse::SingleVlanHeader [−][src]
pub struct SingleVlanHeader {
pub priority_code_point: u8,
pub drop_eligible_indicator: bool,
pub vlan_identifier: u16,
pub ether_type: u16,
}IEEE 802.1Q VLAN Tagging Header
Fields
priority_code_point: u8
A 3 bit number which refers to the IEEE 802.1p class of service and maps to the frame priority level.
drop_eligible_indicator: bool
Indicate that the frame may be dropped under the presence of congestion.
vlan_identifier: u16
12 bits vland identifier.
ether_type: u16
"Tag protocol identifier": Type id of content after this header. Refer to the "EtherType" for a list of possible supported values.
Methods
impl SingleVlanHeader[src]
impl SingleVlanHeaderpub fn read<T: Read + Seek + Sized>(
reader: &mut T
) -> Result<SingleVlanHeader, Error>[src]
pub fn read<T: Read + Seek + Sized>(
reader: &mut T
) -> Result<SingleVlanHeader, Error>Read a IEEE 802.1Q VLAN tagging header
pub fn write<T: Write + Sized>(&self, writer: &mut T) -> Result<(), WriteError>[src]
pub fn write<T: Write + Sized>(&self, writer: &mut T) -> Result<(), WriteError>Write the IEEE 802.1Q VLAN tagging header