Struct etherparse::SingleVlanHeaderSlice [−][src]
pub struct SingleVlanHeaderSlice<'a> { /* fields omitted */ }A slice containing a single vlan header of a network package.
Methods
impl<'a> SingleVlanHeaderSlice<'a>[src]
impl<'a> SingleVlanHeaderSlice<'a>pub fn from_slice(
slice: &'a [u8]
) -> Result<SingleVlanHeaderSlice<'a>, ReadError>[src]
pub fn from_slice(
slice: &'a [u8]
) -> Result<SingleVlanHeaderSlice<'a>, ReadError>Creates a vlan header slice from a slice.
pub fn slice(&self) -> &'a [u8][src]
pub fn slice(&self) -> &'a [u8]Returns the slice containing the single vlan header
pub fn priority_code_point(&self) -> u8[src]
pub fn priority_code_point(&self) -> u8Read the "priority_code_point" field from the slice. This is a 3 bit number which refers to the IEEE 802.1p class of service and maps to the frame priority level.
pub fn drop_eligible_indicator(&self) -> bool[src]
pub fn drop_eligible_indicator(&self) -> boolRead the "drop_eligible_indicator" flag from the slice. Indicates that the frame may be dropped under the presence of congestion.
pub fn vlan_identifier(&self) -> u16[src]
pub fn vlan_identifier(&self) -> u16Reads the 12 bits "vland identifier" field from the slice.
pub fn ether_type(&self) -> u16[src]
pub fn ether_type(&self) -> u16Read the "Tag protocol identifier" field from the slice. Refer to the "EtherType" for a list of possible supported values.
pub fn to_header(&self) -> SingleVlanHeader[src]
pub fn to_header(&self) -> SingleVlanHeaderDecode all the fields and copy the results to a SingleVlanHeader struct