Enum etherparse::TcpOptionElement [−][src]
pub enum TcpOptionElement {
Nop,
MaximumSegmentSize(u16),
WindowScale(u8),
SelectiveAcknowledgementPermitted,
SelectiveAcknowledgement((u32, u32), [Option<(u32, u32)>; 3]),
Timestamp(u32, u32),
}Different kinds of options that can be present in the options part of a tcp header.
Variants
NopMaximumSegmentSize(u16)WindowScale(u8)SelectiveAcknowledgementPermittedSelectiveAcknowledgement((u32, u32), [Option<(u32, u32)>; 3])Timestamp(u32, u32)Timestamp & echo (first number is the sender timestamp, the second the echo timestamp)