Module etherparse::err
source · Expand description
Module containing error types that can be triggered.
Modules
- io
std
Structs
- Error when different lengths are conflicting with each other (e.g. not enough data in a slice to decode a header).
- Error when not enough space is available in a slice to write a packet or header to it.
- Error if a value exceeds the maximum allowed value.
Enums
- “Catch all” error for all
from_sliceerrors (supports automatic conversion from all other slice errors). - Layers on which an error can occur.
- Read
Error std“Catch all” error for allfrom_sliceorreaderrors (supports automatic conversion from all other slice errors). - Types of values that have a limited allowed value range and can cause an
crate::err::ValueTooBigError.