pub enum FromSliceError {
Len(LenError),
LinuxSll(HeaderError),
Macsec(HeaderError),
Ip(HeaderError),
IpAuth(HeaderError),
Ipv4(HeaderError),
Ipv6(HeaderError),
Ipv6Exts(HeaderError),
Tcp(HeaderError),
}Expand description
“Catch all” error for all from_slice errors (supports automatic conversion from all
other slice errors).
This type aggregates all errors that can be caused by decoding from a slice.
This type can be used as a “catch all” type for errors caused by from_slice functions
as all errors from these functions can be converted into this type.
Variants
Len(LenError)
Error when parsing had to be aborted because of a length error (usually not enough data being available).
LinuxSll(HeaderError)
Error when decoding an Linux SLL header.
Macsec(HeaderError)
Error when decoding MACsec header.
Ip(HeaderError)
Error while parsing a IP header.
IpAuth(HeaderError)
Error while parsing a IP authentication header.
Ipv4(HeaderError)
Error while parsing a IPv4 header.
Ipv6(HeaderError)
Error while parsing a IPv6 header.
Ipv6Exts(HeaderError)
Error while parsing a IPv6 extension header.
Tcp(HeaderError)
Error while parsing a TCP extension header.
Implementations
Sourceimpl FromSliceError
impl FromSliceError
pub fn len(&self) -> Option<&LenError>
pub fn linux_sll(&self) -> Option<&HeaderError>
pub fn macsec(&self) -> Option<&HeaderError>
pub fn ip(&self) -> Option<&HeaderError>
pub fn ip_auth(&self) -> Option<&HeaderError>
pub fn ipv4(&self) -> Option<&HeaderError>
pub fn ipv6(&self) -> Option<&HeaderError>
pub fn ipv6_exts(&self) -> Option<&HeaderError>
pub fn tcp(&self) -> Option<&HeaderError>