Struct etherparse::Ethernet2Header
[−]
[src]
pub struct Ethernet2Header {
pub source: [u8; 6],
pub destination: [u8; 6],
pub ether_type: u16,
}Ethernet II header.
Fields
source: [u8; 6]
destination: [u8; 6]
ether_type: u16
Methods
impl Ethernet2Header[src]
pub fn read<T: Read + Seek + Sized>(
reader: &mut T
) -> Result<Ethernet2Header, Error>[src]
reader: &mut T
) -> Result<Ethernet2Header, Error>
Reads an Ethernet-II header from the current position of the read argument.
pub fn write<T: Write + Sized>(&self, writer: &mut T) -> Result<(), Error>[src]
Writes a given Ethernet-II header to the current position of the write argument.